.:TSETMC:. :: Instrument - فهرست و مشخصات نمادها

PSB is being developed by Pooya Paridel.
شركت مديريت فناوري بورس تهران
Tehran Securities Exchange Technology Management Co
Instrument - فهرست و مشخصات نمادها

آدرس | http://service.tsetmc.com/WebService/TsePublicV2.asmx http://service.tsetmc.com/WebService/TsePublicV2.asmx?WSDL
نام سرويس | Instrument
توضيحات | اطلاعات مربوط به نمادها را ارائه مي کند.
پارامترهاي ورودي |
UserName | نام کاربري مشترک
Password | کلمه عبور مشترک
Flow | کد بازار 0 : عمومي - مشترک بين بورس و فرابورس 1 : بورس 2 : فرابورس 3 : آتی 4 : پایه فرابورس 5 : پایه فرابورس (منتشر نمی شود) 6 : بورس انرژی 7 : بورس کالا
خروجي | Dataset حاوي اطلاعات نمادها با ساختار زير: <xs:schema id="Instruments" xmlns="" xmlns:xs=http://www.w3.org/2001/XMLSchema xmlns:msdata="urn:schemas-microsoft-com:xml-msdata"> <xs:element name="Instruments" msdata:IsDataSet="true" msdata:UseCurrentLocale="true"> <xs:complexType> <xs:choice minOccurs="0" maxOccurs="unbounded"> <xs:element name="TseInstruments"> <xs:complexType> <xs:sequence> <xs:element name="DEVen" type="xs:int" minOccurs="0" /> <xs:element name="InsCode" type="xs:long" minOccurs="0" /> <xs:element name="InstrumentID" type="xs:string" minOccurs="0" /> <xs:element name="CValMne" type="xs:string" minOccurs="0" /> <xs:element name="LVal18" type="xs:string" minOccurs="0" /> <xs:element name="CSocCSAC" type="xs:string" minOccurs="0" /> <xs:element name="LSoc30" type="xs:string" minOccurs="0" /> <xs:element name="LVal18AFC" type="xs:string" minOccurs="0" /> <xs:element name="LVal30" type="xs:string" minOccurs="0" /> <xs:element name="CIsin" type="xs:string" minOccurs="0" /> <xs:element name="QNmVlo" type="xs:decimal" minOccurs="0" /> <xs:element name="ZTitad" type="xs:decimal" minOccurs="0" /> <xs:element name="DESop" type="xs:int" minOccurs="0" /> <xs:element name="YOPSJ" type="xs:unsignedByte" minOccurs="0" /> <xs:element name="CGdSVal" type="xs:string" minOccurs="0" /> <xs:element name="CGrValCot" type="xs:string" minOccurs="0" /> <xs:element name="DInMar" type="xs:int" minOccurs="0" /> <xs:element name="YUniExpP" type="xs:unsignedByte" minOccurs="0" /> <xs:element name="YMarNSC" type="xs:string" minOccurs="0" /> <xs:element name="CComVal" type="xs:string" minOccurs="0" /> <xs:element name="CSecVal" type="xs:string" minOccurs="0" /> <xs:element name="CSoSecVal" type="xs:string" minOccurs="0" /> <xs:element name="YDeComp" type="xs:unsignedByte" minOccurs="0" /> <xs:element name="PSaiSMaxOkValMdv" type="xs:decimal" minOccurs="0" /> <xs:element name="PSaiSMinOkValMdv" type="xs:decimal" minOccurs="0" /> <xs:element name="BaseVol" type="xs:long" minOccurs="0" /> <xs:element name="YVal" type="xs:int" minOccurs="0" /> <xs:element name="QPasCotFxeVal" type="xs:int" minOccurs="0" /> <xs:element name="QQtTranMarVal" type="xs:int" minOccurs="0" /> <xs:element name="Flow" type="xs:unsignedByte" minOccurs="0" /> <xs:element name="QtitMinSaiOmProd" type="xs:long" minOccurs="0" /> <xs:element name="QtitMaxSaiOmProd" type="xs:long" minOccurs="0" /> <xs:element name="Valid" type="xs:short" minOccurs="0" /> </xs:sequence> </xs:complexType> </xs:element> </xs:choice> </xs:complexType> </xs:element> </xs:schema>
اطلاعات خروجي |
DEven | تاريخ - نمادهايي که در آخرين روز معاملاتي وجود نداشته باشند داراي تاريخ قديمي بوده و قابل شناسايي هستند
InsCode | کد داخلي نماد - در تمام اطلاعات از اين کد براي شناسايي نماد استفاده مي شود. اين کد براي هر نماد يکتا بوده و در هنگام اضافه شدن هر نماد جديد به بورس, در بانک اطلاعاتي وب سايت شرکت مديريت فناوري بورس ساخته مي شود
InstrumentID | کد 12 رقمي لاتين نماد
CValMne | کد 5 رقمي لاتين نماد
LVal18 | نام 18 رقمي لاتين نماد
CSocCSAC | کد 5 رقمي لاتين شرکت
LSoc30 | نام 30 رقمي فارسي شرکت
LVal18AFC | کد 18 رقمي فارسي نماد
LVal30 | نام 30 رقمي فارسي نماد
CIsin | کد 12 رقمي شرکت
QNmVlo | قيمت اسمي
ZTitad | تعداد سهام - سرمايه
DESop | تاريخ تغيير نماد
YOPSJ | نوع تغيير امروز نماد
CGdSVal | نوع نماد يکي از مقادير: A - I - O
CGrValCot | کد گروه نماد
DInMar | تاريخ اولين روز معاملاتي نماد
YUniExpP | واحد قيمت - 1:قيمت - 2:درصد
YMarNSC | کد بازار NO Normal market OL Odd-lot market BK Block market BY Buying-in market ID Index market UI instruments
CComVal | کد تابلو
CSecVal | کد گروه صنعت
CSoSecVal | کد زير گروه صنعت
YDeComp | ميزان تاخير تصويه
PSaiSMaxOkValMdv | حداکثر قيمت مجاز
PSaiSMinOkValMdv | حداقل قيمت مجاز
BaseVol | حجم مبنا
- YVal | نوع نماد:
  67 | شاخص | شاخص قيمت
  68 | شاخص | شاخص
  208 | اوراق مشاركت | اوراق صكوك
  300 | سهام عادي | سهام
  305 | صندوق سرمايه گذاري | صندوق سرمايه گذاري در سهام بورس
  309 | تست پایه | تست پایه
  321 | اختیار فولاد هرمزگان |
  322 | اختیار خ اخزا ( اسناد خزانه داری اسلامی ) |
  323 | اختیارف اخزا ( اسناد خزانه داری اسلامی ) |
  400 | حق تقدم | حق تقدم سهم
  69 | شاخص | شاخص فرابورس
  70 | اوراق مشاركت | صکوک اختصاصی
  303 | سهام عادی | اتیسی
  305 | صندوق سرمايه گذاري | صندوق سرمايه گذاري در سهام بورس
  306 | اوراق مشاركت | اوراق مشارکت اتیسی
  307 | سهام عادی | تسهیلات فرابورس
  313 | سهام عادی | شرکتهای کوچک و متوسط
  403 | حق تقدم | حق تقدم اتیسی
  601 | اختیار فروش تبعی ( ذوب آهن اصفهان) |
  706 | اوراق مشاركت | صکوک اختصاصی
  903 | دارایی فکری | دارایی فکری
  301 | اوراق مشاركت | اوراق مشارکت
  304 | سهام عادی | آتی
  311 | سهام عادی | اختیار خرید
  312 | سهام عادی | اختیار فروش
  600 | اختیار | اختیار فروش تبعی
  602 | اختیار | اختیار فروش تبعی فرابورس
  309 | سهام عادی | پایه
  404 | حق تقدم | حق تقدم پایه
  207 | اوراق مشاركت | اوراق مشارکت ارز صادراتی
  200 | اوراق مشاركت | اوراق مشارکت انرژی
  315 | صندوق سرمايه گذاري | صندوق سرمایه گذاری قابل معامله انرژی
  801 | سلف بورس انرژی |
  802 | سلف بورس انرژی |
  803 | سلف بورس انرژی |
  804 | سلف بورس انرژی |
  901 | انرژی |
  902 | انرژی |
  308 | اوراق مشاركت | اوراق مشارکت کالا
  701 | کالا | گواهی سپرده کالایی
QPasCotFxeVal | تيک - کوچک ترين واحد قيمتي قابل معامله - قيمت فقط ضريبي از اين مقدار مي تواند باشد.
ًQQtTranMarVal | کوچک ترين تعداد سهام قابل معامله - تعداد سهام فقط ضريبي از اين مقدار مي تواند باشد.
Flow | بازار: 0 : عمومي - مشترک بين بورس و فرابورس 1 : بورس 2 : فرابورس 3 : آتی 4 : پایه فرابورس 5 : پایه فرابورس (منتشر نمی شود) 6 : بورس انرژی 7 : بورس کالا
QtitMinSaiOmProd | حداقل حجم مجاز قابل سفارش.
ًQtitMaxSaiOmProd | حداکثر حجم مجاز قابل سفارش.
Valid | اعتبار نماد : 0 : قدیمی و حذف شده 1 : معتبر